@@ -123,14 +123,14 @@ val mem_installed :
   universe -> vpkg -> bool
 
 (** Ask who provides a given feature (predicate).
-    Note: only installed=true packages are considered by this function.
+    @param installed : consider only installed packages (default)
 
     @return a list of packages providing the requested feature. Each
     package is paired with an optional version; if it is None, the
     given package provides all possible version of the feature; it if
     is Some v, the given package only provides version [v] of the
     feature. *)
-val who_provides : universe -> vpkg -> (package * version option) list
+val who_provides : ?installed:bool -> universe -> vpkg -> (package * version option) list
 
 (** lookup all available versions of a given package name
 
@@ -142,9 +142,27 @@ val lookup_packages : ?filter:constr -> universe -> pkgname -> package list
     Shorthand for [lookup_packages] composed with filtering on installed=true *)
 val get_installed : universe -> pkgname -> package list
 
+(** return a unique integer identifier for the given package in the universe
+
+    @raise Not_found if the given package cannot be found in the universe *)
+val uid_by_package : universe -> package -> int
+
+(** return the package corresponding to the given unique identifier
+
+    @raise Not_found if no package in the universe corresponds to the given
+    unique identifier *)
+val package_by_uid : universe -> int -> package
+
+(** iter over all packages in the universe *)
 val iter_packages : (package -> unit) -> universe -> unit
+
+(** fold over all packages in the universe *)
 val fold_packages : ('a -> package -> 'a) -> 'a -> universe -> 'a
 
+(** iter on all packages in the universe, passing to the iteration function
+    both the package and its unique identifier *)
+val iteri_packages : (int -> package -> unit) -> universe -> unit
+
 (** conversion from universe to plain package list
 
     @param filter only return packages matching a given
